Skip to contents

Fits a regression model using only complete cases, defined by D = 1, via M-estimation using the geex framework. This is the complete-case analogue of estimate_beta, and is primarily intended for comparison in simulation studies. Not consistent under outcome dependent censoring.

Usage

estimate_beta_cc(data_yXZ, model)

Arguments

data_yXZ

A data frame containing at least the variables in model and a binary indicator D, where D = 1 denotes a complete case.

model

An object of class formula specifying the regression model for the outcome.

Value

A list with components

beta_est

A 1 x (p + 1) matrix of regression coefficients followed by the residual standard deviation (last element).

se_est

A 1 x p matrix of estimated standard errors for the regression coefficients.