AIPW lambda-close estimator
estimate_beta_aipw_lambda.RdFits a regression model for y using an augmented IPW estimator
with a closed-form ("lambda-close") augmentation under a normal
approximation for X. This implementation assumes the outcome
model is y ~ AW + Z, where AW = A - X, and uses a
single covariate Z in the outcome model.
Usage
estimate_beta_aipw_lambda(
data_yXZ = dat,
model = model,
model_weights = model_weights,
aw_var = "AW"
)Arguments
- data_yXZ
Data frame containing at least
y, A, AW, W, D, Z, and the weight variablesmyp_ywz_oracle,myp_ywz,myp_uniform,myp_ywz_logit. Assumes the outcome model isy ~ AW + Z.- model
Formula for the outcome, currently assumed to be
y ~ AW + Z. The function checks that the design matrix has exactly three columns: intercept, AW, and Z, in that order.- model_weights
A
formulaspecifying the censoring model forC | (Y, Z, ...). Typically a right-hand-side only formula, such as~ y + Z, which is internally expanded toSurv(W, 1 - D) ~ y + Z.- aw_var
Character string giving the name of the exposure covariate in
modelthat equalsA - X(default"AW"). This must appear inmodeland indata_yXZ.