Complete-case estimator for regression parameters
estimate_beta_cc.RdFits a regression model using only complete cases, defined by D = 1,
via M-estimation using the geex framework. This is the complete-case
analogue of estimate_beta, and is primarily intended for
comparison in simulation studies. Not consistent under outcome dependent censoring.
Arguments
- data_yXZ
A data frame containing at least the variables in
modeland a binary indicatorD, whereD = 1denotes a complete case.- model
An object of class
formulaspecifying the regression model for the outcome.