Inverse probability weighted (IPW) estimator for regression parameters
estimate_beta_ipw.RdFits a regression model using inverse probability weighting, where the
weights are derived from a parametric model for the censoring distribution
C | (Y, Z, ...). The user supplies a right-hand-side formula (e.g.
~ y + Z) which is used to model Surv(W, 1 - D) via a Weibull
AFT model. The resulting estimated survival probabilities at W are
used as weights in the IPW estimating equations.
Arguments
- data_yXZ
A data frame containing the variables in
model, as well asW(observedmin(X, C)),D(indicatorI(X <= C)), and the covariates appearing inmodel_weights.- model
A
formulaspecifying the outcome regression model (e.g.y ~ AW + Z).- model_weights
A right-hand-side formula specifying the variables in the censoring model, e.g.
~ y + Z. This will be expanded toSurv(W, 1 - D) ~ y + Zinternally.